@@ -1,4 +1,5 @@
 /*
+ *  Copyright (c) 2016, Peter Haag
  *  Copyright (c) 2014, Peter Haag
  *  Copyright (c) 2009, Peter Haag
  *  Copyright (c) 2004-2008, SWITCH - Teleinformatikdienste fuer Lehre und Forschung
@@ -28,12 +29,7 @@
  *  ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
  *  POSSIBILITY OF SUCH DAMAGE.
  *  
- *  $Author: haag $
- *
- *  $Id: nfcapd.c 51 2010-01-29 09:01:54Z haag $
- *
- *  $LastChangedRevision: 51 $
- *	
+ *  Author: peter
  *
  */
 
@@ -153,7 +149,7 @@ static void daemonize(void);
 static void SetPriv(char *userid, char *groupid );
 
 static void run(packet_function_t receive_packet, int socket, send_peer_t peer, 
-	time_t twin, time_t t_begin, int report_seq, int use_subdirs, int compress, int do_xstat);
+	time_t twin, time_t t_begin, int report_seq, int use_subdirs, char *time_extension, int compress, int do_xstat);
 
 /* Functions */
 static void usage(char *name) {
@@ -164,7 +160,7 @@ static void usage(char *name) {
 					"-w\t\tSync file rotation with next 5min (default) interval\n"
 					"-t interval\tset the interval to rotate nfcapd files\n"
 					"-b host\t\tbind socket to host/IP addr\n"
-					"-j mcastgroup\tJoin multicast group <mcastgroup>\n"
+					"-J mcastgroup\tJoin multicast group <mcastgroup>\n"
 					"-p portnum\tlisten on port portnum\n"
 					"-l basdir \tset the output directory. (no default) \n"
 					"-S subdir\tSub directory format. see nfcapd(1) for format\n"
@@ -175,7 +171,8 @@ static void usage(char *name) {
 					"-R IP[/port]\tRepeat incoming packets to IP address/port\n"
 					"-s rate\tset default sampling rate (default 1)\n"
 					"-x process\tlaunch process after a new file becomes available\n"
-					"-z\t\tCompress flows in output file.\n"
+					"-j\t\tBZ2 compress flows in output file.\n"
+					"-z\t\tLZO compress flows in output file.\n"
 					"-B bufflen\tSet socket buffer to bufflen bytes\n"
 					"-e\t\tExpire data at each cycle.\n"
 					"-D\t\tFork to background\n"
@@ -184,6 +181,7 @@ static void usage(char *name) {
 					"-4\t\tListen on IPv4 (default).\n"
 					"-6\t\tListen on IPv6.\n"
 					"-V\t\tPrint version and exit.\n"
+					"-Z\t\tAdd timezone offset to filenamet.\n"
 					, name);
 } // End of usage
 
@@ -362,7 +360,7 @@ int		err;
 #include "collector_inline.c"
 
 static void run(packet_function_t receive_packet, int socket, send_peer_t peer, 
-	time_t twin, time_t t_begin, int report_seq, int use_subdirs, int compress, int do_xstat) {
+	time_t twin, time_t t_begin, int report_seq, int use_subdirs, char *time_extension, int compress, int do_xstat) {
 common_flow_header_t	*nf_header;
 FlowSource_t			*fs;
 struct sockaddr_storage nf_sender;
@@ -468,10 +466,11 @@ srecord_t	*commbuff;
 		if ( ((t_now - t_start) >= twin) || done ) {
 			char subfilename[64];
 			struct  tm *now;
-			char	*subdir;
+			char	*subdir, fmt[64];
 
 			alarm(0);
 			now = localtime(&t_start);
+			strftime(fmt, sizeof fmt, time_extension, now);
 
 			// prepare sub dir hierarchy
 			if ( use_subdirs ) {
@@ -482,16 +481,13 @@ srecord_t	*commbuff;
 			
 					// failed to generate subdir path - put flows into base directory
 					subdir = NULL;
-					snprintf(subfilename, 63, "nfcapd.%i%02i%02i%02i%02i",
-						now->tm_year + 1900, now->tm_mon + 1, now->tm_mday, now->tm_hour, now->tm_min);
+					snprintf(subfilename, 63, "nfcapd.%s", fmt);
 				} else {
-					snprintf(subfilename, 63, "%s/nfcapd.%i%02i%02i%02i%02i", subdir,
-						now->tm_year + 1900, now->tm_mon + 1, now->tm_mday, now->tm_hour, now->tm_min);
+					snprintf(subfilename, 63, "%s/nfcapd.%s", subdir, fmt);
 				}
 			} else {
 				subdir = NULL;
-				snprintf(subfilename, 63, "nfcapd.%i%02i%02i%02i%02i",
-					now->tm_year + 1900, now->tm_mon + 1, now->tm_mday, now->tm_hour, now->tm_min);
+				snprintf(subfilename, 63, "nfcapd.%s", fmt);
 			}
 			subfilename[63] = '\0';
 
@@ -764,7 +760,7 @@ int main(int argc, char **argv) {
  
 char	*bindhost, *filter, *datadir, pidstr[32], *launch_process;
 char	*userid, *groupid, *checkptr, *listenport, *mcastgroup, *extension_tags;
-char	*Ident, *dynsrcdir, pidfile[MAXPATHLEN];
+char	*Ident, *dynsrcdir, *time_extension, pidfile[MAXPATHLEN];
 struct stat fstat;
 packet_function_t receive_packet;
 send_peer_t  peer;
@@ -772,7 +768,7 @@ FlowSource_t *fs;
 struct sigaction act;
 int		family, bufflen;
 time_t 	twin, t_start;
-int		sock, synctime, do_daemonize, expire, report_sequence, do_xstat;
+int		sock, synctime, do_daemonize, expire, spec_time_extension, report_sequence, do_xstat;
 int		subdir_index, sampling_rate, compress;
 int		c;
 #ifdef PCAP
@@ -798,9 +794,11 @@ char	*pcap_file;
 	twin	 		= TIME_WINDOW;
 	datadir	 		= NULL;
 	subdir_index	= 0;
+	time_extension	= "%Y%m%d%H%M";
+	spec_time_extension = 0;
 	expire			= 0;
 	sampling_rate	= 1;
-	compress		= 0;
+	compress		= NOT_COMPRESSED;
 	do_xstat		= 0;
 	memset((void *)&peer, 0, sizeof(send_peer_t));
 	peer.family		= AF_UNSPEC;
@@ -809,7 +807,7 @@ char	*pcap_file;
 	extension_tags	= DefaultExtensions;
 	dynsrcdir		= NULL;
 
-	while ((c = getopt(argc, argv, "46ef:whEVI:DB:b:j:l:M:n:p:P:R:S:s:T:t:x:Xru:g:z")) != EOF) {
+	while ((c = getopt(argc, argv, "46ef:whEVI:DB:b:jl:J:M:n:p:P:R:S:s:T:t:x:Xru:g:zZ")) != EOF) {
 		switch (c) {
 			case 'h':
 				usage(argv[0]);
@@ -889,7 +887,7 @@ char	*pcap_file;
 			case 'b':
 				bindhost = optarg;
 				break;
-			case 'j':
+			case 'J':
 				mcastgroup = optarg;
 				break;
 			case 'p':
@@ -973,8 +971,23 @@ char	*pcap_file;
 			case 'x':
 				launch_process = optarg;
 				break;
+			case 'j':
+				if ( compress ) {
+					LogError("Use either -z for LZO or -j for BZ2 compression, but not both\n");
+					exit(255);
+				}
+				compress = BZ2_COMPRESSED;
+				break;
 			case 'z':
-				compress = 1;
+				if ( compress ) {
+					LogError("Use either -z for LZO or -j for BZ2 compression, but not both\n");
+					exit(255);
+				}
+				compress = LZO_COMPRESSED;
+				break;
+			case 'Z':
+				time_extension	= "%Y%m%d%H%M%z";
+				spec_time_extension = 1;
 				break;
 			case '4':
 				if ( family == AF_UNSPEC )
@@ -1016,6 +1029,11 @@ char	*pcap_file;
 		exit(255);
 	}
 
+	if ( expire && spec_time_extension ) {
+		fprintf(stderr, "ERROR, -Z timezone extension breaks expire -e\n");
+		exit(255);
+	}
+
 	InitExtensionMaps(NO_EXTENSION_LIST);
 	SetupExtensionDescriptors(strdup(extension_tags));
 
@@ -1207,7 +1225,8 @@ char	*pcap_file;
 	sigaction(SIGCHLD, &act, NULL);
 
 	LogInfo("Startup.");
-	run(receive_packet, sock, peer, twin, t_start, report_sequence, subdir_index, compress, do_xstat);
+	run(receive_packet, sock, peer, twin, t_start, report_sequence, subdir_index, 
+		time_extension, compress, do_xstat);
 	close(sock);
 	kill_launcher(launcher_pid);
 
