@@ -271,6 +271,7 @@ lnf_field_t lnf_fields[] = {
 int lnf_open(lnf_file_t **lnf_filep, const char * filename, unsigned int flags, const char * ident) {
 	int i;
 	lnf_file_t *lnf_file;
+	int comp;
 
 	lnf_file = malloc(sizeof(lnf_file_t));
 	
@@ -290,7 +291,15 @@ int lnf_open(lnf_file_t **lnf_filep, const char * filename, unsigned int flags,
 
 	} else if (flags & LNF_WRITE) {
 
-		lnf_file->nffile = OpenNewFile((char *)filename, NULL, flags & LNF_COMP, 
+		if (flags & LNF_COMP_LZO) {
+			comp = 1; 
+		} else if (flags & LNF_COMP_BZ2) { 
+			comp = 2; 
+		} else {
+			comp = 0;
+		}
+
+		lnf_file->nffile = OpenNewFile((char *)filename, NULL, comp, 
 								flags & LNF_ANON, (char *)ident);
 
 	} else {
@@ -316,6 +325,7 @@ int lnf_open(lnf_file_t **lnf_filep, const char * filename, unsigned int flags,
 #endif
 	lnf_file->extension_map_list = InitExtensionMaps(NEEDS_EXTENSION_LIST);
 
+	lnf_file->v1convert_buffer = NULL;
 	lnf_file->lnf_map_list = NULL;
 
 	i = 1;
@@ -379,7 +389,15 @@ int lnf_info(lnf_file_t *lnf_file, int info, void *data, size_t size) {
 			reqsize = sizeof(uint64_t);
 			break;
 		case LNF_INFO_COMPRESSED:
-			*((int *)buf) = h->flags & FLAG_COMPRESSED;
+			*((int *)buf) = FILE_IS_LZO_COMPRESSED(lnf_file->nffile) || FILE_IS_BZ2_COMPRESSED(lnf_file->nffile) ;
+			reqsize = sizeof(int);
+			break;
+		case LNF_INFO_LZO_COMPRESSED:
+			*((int *)buf) = FILE_IS_LZO_COMPRESSED(lnf_file->nffile);
+			reqsize = sizeof(int);
+			break;
+		case LNF_INFO_BZ2_COMPRESSED:
+			*((int *)buf) = FILE_IS_BZ2_COMPRESSED(lnf_file->nffile);
 			reqsize = sizeof(int);
 			break;
 		case LNF_INFO_ANONYMIZED:
@@ -460,6 +478,8 @@ int lnf_info(lnf_file_t *lnf_file, int info, void *data, size_t size) {
 /* close file handler and release related structures */
 void lnf_close(lnf_file_t *lnf_file) {
 
+	lnf_map_list_t *map_list, *tmp_map_list;
+
 	if (lnf_file == NULL || lnf_file->nffile == NULL) {
 		return ;
 	}
@@ -483,6 +503,21 @@ void lnf_close(lnf_file_t *lnf_file) {
 	PackExtensionMapList(lnf_file->extension_map_list);
 	FreeExtensionMaps(lnf_file->extension_map_list);
 
+	map_list = lnf_file->lnf_map_list; 
+	while (map_list != NULL) {
+		tmp_map_list = map_list;
+		map_list = map_list->next;
+		bit_array_release(&tmp_map_list->bit_array);
+		if (tmp_map_list->map != NULL) {
+			free(tmp_map_list->map);
+		}
+		free(tmp_map_list);
+	}
+
+	if (lnf_file->v1convert_buffer != NULL) {
+		free(lnf_file->v1convert_buffer);
+	}
+
 	free(lnf_file);
 }
 
@@ -495,6 +530,7 @@ int ret;
 uint32_t map_id;
 extension_map_t *map;
 int i;
+common_record_t *common_record_ptr;
 
 #ifdef COMPAT15
 int	v1_map_done = 0;
@@ -570,8 +606,22 @@ begin:
 				break;
 			
 		case CommonRecordV0Type:
+
+				// convert common record v0
+				if ( lnf_file->v1convert_buffer == NULL) {
+					lnf_file->v1convert_buffer = malloc(65536); /* very suspisous part of code taken from nfdump */
+					if ( lnf_file->v1convert_buffer == NULL ) {
+						return LNF_ERR_NOMEM;
+					}
+				}
+				ConvertCommonV0((void *)lnf_file->flow_record, (common_record_t *)lnf_file->v1convert_buffer);
+				common_record_ptr = (common_record_t *)lnf_file->v1convert_buffer;
+
+				break;
+
 		case CommonRecordType:
 				/* data record type - go ahead */
+				common_record_ptr = lnf_file->flow_record;
 				break;
 
 		default:
@@ -594,7 +644,7 @@ begin:
 
 	// changed in 1.6.8 - added exporter info 
 //	ExpandRecord_v2( flow_record, extension_map_list.slot[map_id], master_record);
-	ExpandRecord_v2(lnf_file->flow_record, lnf_file->extension_map_list->slot[map_id], NULL, lnf_rec->master_record);
+	ExpandRecord_v2(common_record_ptr, lnf_file->extension_map_list->slot[map_id], NULL, lnf_rec->master_record);
 
 	// update number of flows matching a given map
 	lnf_file->extension_map_list->slot[map_id]->ref_count++;
@@ -672,6 +722,7 @@ int map_id = 0;
 	// allocate memory potentially for all extensions 
 	map = malloc(sizeof(extension_map_t) + (lnf_file->max_num_extensions + 1) * sizeof(uint16_t));
 	if (map == NULL) {
+		free(map_list);
 		return NULL;
 	}
 
@@ -864,6 +915,7 @@ void lnf_rec_free(lnf_rec_t *rec) {
 				free(rec->field_data[i]);
 			}
 		}
+		free(rec->field_data);
 	}
 	free(rec);
 }
@@ -989,4 +1041,9 @@ va_list args;
 /* empry functions - required by nfdump */
 void LogInfo(char *format, ...) { }
 void format_number(uint64_t num, char *s, int scale, int fixed_width) { } 
+/* dummy functions from flist.c */
+char *GetCurrentFilename(void) { return NULL; } 
+nffile_t *GetNextFile(nffile_t *nffile, time_t twin_start, time_t twin_end) { return NULL; }
+void SetupInputFileSequence(char *multiple_dirs, char *single_file, char *multiple_files) { }
+
 
