@@ -47,6 +47,7 @@
 #endif
 #include "bit_array.h"
 #include "hash_table.h"
+#include "ffilter.h"
 
 #ifndef HAVE_HTONLL
 #ifdef WORDS_BIGENDIAN
@@ -75,7 +76,8 @@ typedef struct lnf_filter_s {
 
 	/* structures for new filter */
 	//lnf_filter_node_t	*root;
-	void				*root;
+	//void				*root;
+	ff_t				*ff_filter;
 
 } lnf_filter_t;
 
@@ -105,6 +107,7 @@ typedef struct lnf_file_s {
 	lnf_map_list_t			*lnf_map_list;			/* internal list of maps (used by lnf) */
 	int						max_num_extensions;		/* the max number of extensions */
 	common_record_t 		*flow_record;			/* ptr to buffer/next record */
+	char					*v1convert_buffer;		/* convert buffer for V1 record types */
 //	master_record_t			*master_record;
 //	lnf_rec_t				*lnf_rec;				/* temporary */
 //	bit_array_t				extensions_arr;			/* structure initialised at the beginging to store bitt array of extensions from last record */
@@ -220,5 +223,9 @@ typedef struct lnf_fastaggr_s {
 } lnf_fastaggr_t;
 
 
+/* filter operations - callbacks */
+ff_error_t lnf_ff_lookup_func(ff_t *filter, const char *fieldstr, ff_lvalue_t *lvalue);
+ff_error_t lnf_ff_data_func(ff_t *filter, void *rec, ff_extern_id_t id, char *data, size_t *size);
+
 #endif /* _LIBNF_INTERNAL_H */
 
